ensure_complete_tidyped: Internal helper to ensure ped is a complete tidyped object

View source: R/utils-s3.R

ensure_complete_tidypedR Documentation

Internal helper to ensure ped is a complete tidyped object

Description

Like ensure_tidyped(), but also rejects row-truncated pedigree subsets whose referenced parents are no longer present.

Usage

ensure_complete_tidyped(ped, fun)

Arguments

ped

An object expected to be a complete tidyped pedigree.

fun

Character scalar. Calling function name for the error message.

Value

A valid, structurally complete tidyped object.


visPedigree documentation built on March 30, 2026, 9:07 a.m.