ensure_tidyped: Internal helper to ensure ped is a tidyped object

View source: R/utils-s3.R

ensure_tidypedR Documentation

Internal helper to ensure ped is a tidyped object

Description

If the object has lost its tidyped class (e.g., after merge(), rbind(), or dplyr operations) but still contains the required columns, the class is automatically restored with an informational message. Otherwise, an error is raised guiding the user to call tidyped() or as_tidyped().

Usage

ensure_tidyped(ped)

Arguments

ped

An object expected to be a tidyped.

Value

A valid tidyped object.


visPedigree documentation built on March 30, 2026, 9:07 a.m.