half_founder_ped: A pedigree with half founders

half_founder_pedR Documentation

A pedigree with half founders

Description

A dataset from ENDOG containing individuals with a single missing parent (half founders). Useful for testing genetic algorithms correctly conserving probability mass for missing lineages.

Usage

half_founder_ped

Format

A data.frame with 4 columns:

Ind

Individual ID

Sire

Sire ID

Dam

Dam ID

Sex

Sex of the individual


visPedigree documentation built on March 30, 2026, 9:07 a.m.