pedecg: Calculate Equi-Generate Coefficient

pedecgR Documentation

Calculate Equi-Generate Coefficient

Description

Estimates the number of distinct ancestral generations using the Equi-Generate Coefficient (ECG). The ECG is calculated as 1/2 of the sum of the parents' ECG values plus 1.

Usage

pedecg(ped)

Arguments

ped

A tidyped object.

Value

A data.table with columns:

  • Ind: Individual ID.

  • ECG: Equi-Generate Coefficient.

  • FullGen: Fully traced generations (depth of complete ancestry).

  • MaxGen: Maximum ancestral generations (depth of deepest ancestor).

References

Boichard, D., Maignel, L., & Verrier, E. (1997). The value of using probabilities of gene origin to measure genetic variability in a population. Genetics Selection Evolution, 29(1), 5.

Examples

tp <- tidyped(simple_ped)
ecg <- pedecg(tp)

# ECG combines pedigree depth and completeness
head(ecg)

# Individuals with deeper and more complete ancestry have larger ECG values
ecg[order(-ECG)][1:5]


visPedigree documentation built on March 30, 2026, 9:07 a.m.