plot.tidyped: Plot a tidy pedigree

View source: R/utils-s3.R

plot.tidypedR Documentation

Plot a tidy pedigree

Description

Plot a tidy pedigree

Usage

## S3 method for class 'tidyped'
plot(x, ...)

Arguments

x

A tidyped object.

...

Additional arguments passed to visped.

Value

Invisibly returns a list of graph data from visped (node/edge data and layout components) used to render the pedigree; the primary result is the plot drawn on the current device.


visPedigree documentation built on March 30, 2026, 9:07 a.m.