Compact pedigree by merging full siblings for matrix calculation
Source:R/pedmatrix.R
compact_ped_for_matrix.RdThis internal function identifies full siblings (individuals sharing the same sire and dam) and selects one representative per family. This can dramatically reduce memory requirements when calculating relationship matrices for pedigrees with large full-sibling families.