| complex_ped | R Documentation |
A dataset containing a large, complex pedigree covering about 100 generations, useful for testing the performance and accuracy of partial inbreeding and similar calculations.
complex_ped
A data.table with a standard pedigree structure.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.