Skip to contents

If the object has lost its tidyped class (e.g., after merge(), rbind(), or dplyr operations) but still contains the required columns, the class is automatically restored with an informational message. Otherwise, an error is raised guiding the user to call tidyped() or as_tidyped().

Usage

ensure_tidyped(ped)

Arguments

ped

An object expected to be a tidyped.

Value

A valid tidyped object.