| ensure_tidyped | R Documentation |
If the object has lost its tidyped class (e.g., after merge(),
rbind(), or dplyr operations) but still contains the required columns,
the class is automatically restored with an informational message. Otherwise,
an error is raised guiding the user to call tidyped() or
as_tidyped().
ensure_tidyped(ped)
ped |
An object expected to be a tidyped. |
A valid tidyped object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.