| half_founder_ped | R Documentation |
A dataset from ENDOG containing individuals with a single missing parent (half founders). Useful for testing genetic algorithms correctly conserving probability mass for missing lineages.
half_founder_ped
A data.frame with 4 columns:
Individual ID
Sire ID
Dam ID
Sex of the individual
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.