Learn R Programming

visPedigree (version 0.7.1)

inbreed: Calculate inbreeding coefficients

Description

inbreed function calculates the inbreeding coefficients for all individuals in a tidied pedigree.

Usage

inbreed(ped, ...)

Value

A tidyped object with an additional column f.

Arguments

ped

A tidyped object.

...

Additional arguments passed to makeDiiF.

Details

This function takes a pedigree tidied by the tidyped function and calculates the inbreeding coefficients using the makeDiiF function from the nadiv package. It prefers using numeric columns (IndNum, SireNum, DamNum) if available, which is faster and more robust.