inbreed function calculates the inbreeding coefficients for all individuals in a tidied pedigree.
inbreed(ped, ...)A tidyped object with an additional column f.
A tidyped object.
Additional arguments passed to makeDiiF.
This function takes a pedigree tidied by the tidyped function and calculates the inbreeding coefficients using the makeDiiF function from the nadiv package. It prefers using numeric columns (IndNum, SireNum, DamNum) if available, which is faster and more robust.