| pedecg | R Documentation |
Estimates the number of distinct ancestral generations using the Equi-Generate Coefficient (ECG). The ECG is calculated as 1/2 of the sum of the parents' ECG values plus 1.
pedecg(ped)
ped |
A |
A data.table with columns:
Ind: Individual ID.
ECG: Equi-Generate Coefficient.
FullGen: Fully traced generations (depth of complete ancestry).
MaxGen: Maximum ancestral generations (depth of deepest ancestor).
Boichard, D., Maignel, L., & Verrier, E. (1997). The value of using probabilities of gene origin to measure genetic variability in a population. Genetics Selection Evolution, 29(1), 5.
tp <- tidyped(simple_ped)
ecg <- pedecg(tp)
# ECG combines pedigree depth and completeness
head(ecg)
# Individuals with deeper and more complete ancestry have larger ECG values
ecg[order(-ECG)][1:5]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.