Validates a tidyped object. If the object has lost its class but retains the
required columns, it is automatically restored via ensure_tidyped().
Fatal structural problems (e.g., missing core columns) raise an error.
Validates a tidyped object. If the object has lost its class but retains the
required columns, it is automatically restored via ensure_tidyped().
Fatal structural problems (e.g., missing core columns) raise an error.